@@ -40,5 +40,7 @@ class myserver(inferServer):
 if __name__ == '__main__':
     mymodel = lambda x: x * 2
     myserver = myserver(mymodel)
+    #myserver.set_property("show_exception", True)
+    
     #run your server, defult ip=localhost port=8080 debuge=false
-    myserver.run(debuge=True) #myserver.run("127.0.0.1", 1234)
+    myserver.run(debuge=False) #myserver.run("127.0.0.1", 1234)
